# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedMethod
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Datastore
from pyVmomi.vim import Folder
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Network
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import ServiceLocator
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.customization import IPSettings

class FailoverClusterConfigurator(ManagedObject):
   class ClusterNetworkConfigSpec(DynamicData):
      networkPortGroup: Network
      ipSettings: IPSettings

   class SourceNodeSpec(DynamicData):
      managementVc: ServiceLocator
      activeVc: VirtualMachine

   class NodeNetworkSpec(DynamicData):
      ipSettings: IPSettings

   class PassiveNodeNetworkSpec(NodeNetworkSpec):
      failoverIpSettings: Optional[IPSettings] = None

   class VchaClusterNetworkSpec(DynamicData):
      witnessNetworkSpec: NodeNetworkSpec
      passiveNetworkSpec: PassiveNodeNetworkSpec

   class NodeDeploymentSpec(DynamicData):
      esxHost: Optional[HostSystem] = None
      datastore: Optional[Datastore] = None
      publicNetworkPortGroup: Optional[Network] = None
      clusterNetworkPortGroup: Optional[Network] = None
      folder: Folder
      resourcePool: Optional[ResourcePool] = None
      managementVc: Optional[ServiceLocator] = None
      nodeName: str
      ipSettings: IPSettings

   class PassiveNodeDeploymentSpec(NodeDeploymentSpec):
      failoverIpSettings: Optional[IPSettings] = None

   class VchaClusterConfigSpec(DynamicData):
      passiveIp: str
      witnessIp: str

   class VchaClusterDeploymentSpec(DynamicData):
      passiveDeploymentSpec: PassiveNodeDeploymentSpec
      witnessDeploymentSpec: NodeDeploymentSpec
      activeVcSpec: SourceNodeSpec
      activeVcNetworkConfig: Optional[ClusterNetworkConfigSpec] = None

   class FailoverNodeInfo(DynamicData):
      clusterIpSettings: IPSettings
      failoverIp: Optional[IPSettings] = None
      biosUuid: Optional[str] = None

   class WitnessNodeInfo(DynamicData):
      ipSettings: IPSettings
      biosUuid: Optional[str] = None

   class VchaState(Enum):
      configured: ClassVar['VchaState'] = 'configured'
      notConfigured: ClassVar['VchaState'] = 'notConfigured'
      invalid: ClassVar['VchaState'] = 'invalid'
      prepared: ClassVar['VchaState'] = 'prepared'

   class VchaClusterConfigInfo(DynamicData):
      failoverNodeInfo1: Optional[FailoverNodeInfo] = None
      failoverNodeInfo2: Optional[FailoverNodeInfo] = None
      witnessNodeInfo: Optional[WitnessNodeInfo] = None
      state: str

   @property
   def disabledConfigureMethod(self) -> list[ManagedMethod]: ...

   def Prepare(self, networkSpec: VchaClusterNetworkSpec) -> Task: ...
   def Deploy(self, deploymentSpec: VchaClusterDeploymentSpec) -> Task: ...
   def Configure(self, configSpec: VchaClusterConfigSpec) -> Task: ...
   def CreatePassiveNode(self, passiveDeploymentSpec: PassiveNodeDeploymentSpec, sourceVcSpec: SourceNodeSpec) -> Task: ...
   def CreateWitnessNode(self, witnessDeploymentSpec: NodeDeploymentSpec, sourceVcSpec: SourceNodeSpec) -> Task: ...
   def GetConfig(self) -> VchaClusterConfigInfo: ...
   def Destroy(self) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanCompliantFirmware

class VsanHclDeviceConstraint(DynamicData):
   pciId: str
   vcgLink: Optional[str] = None
   similarVcgLinks: list[str] = []
   compliantFirmwares: list[VsanCompliantFirmware] = []
   vcgId: Optional[int] = None
   model: Optional[str] = None
   partner: Optional[str] = None
   partNumber: Optional[str] = None
   release: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class IpConfig(DynamicData):
   class IpV6AddressConfigType(Enum):
      other: ClassVar['IpV6AddressConfigType'] = 'other'
      manual: ClassVar['IpV6AddressConfigType'] = 'manual'
      dhcp: ClassVar['IpV6AddressConfigType'] = 'dhcp'
      linklayer: ClassVar['IpV6AddressConfigType'] = 'linklayer'
      random: ClassVar['IpV6AddressConfigType'] = 'random'

   class IpV6AddressStatus(Enum):
      preferred: ClassVar['IpV6AddressStatus'] = 'preferred'
      deprecated: ClassVar['IpV6AddressStatus'] = 'deprecated'
      invalid: ClassVar['IpV6AddressStatus'] = 'invalid'
      inaccessible: ClassVar['IpV6AddressStatus'] = 'inaccessible'
      unknown: ClassVar['IpV6AddressStatus'] = 'unknown'
      tentative: ClassVar['IpV6AddressStatus'] = 'tentative'
      duplicate: ClassVar['IpV6AddressStatus'] = 'duplicate'

   class IpV6Address(DynamicData):
      ipAddress: str
      prefixLength: int
      origin: Optional[str] = None
      dadState: Optional[str] = None
      lifetime: Optional[datetime] = None
      operation: Optional[str] = None

   class IpV6AddressConfiguration(DynamicData):
      ipV6Address: list[IpV6Address] = []
      autoConfigurationEnabled: Optional[bool] = None
      dhcpV6Enabled: Optional[bool] = None

   dhcp: bool
   ipAddress: Optional[str] = None
   subnetMask: Optional[str] = None
   ipV6Config: Optional[IpV6AddressConfiguration] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import DataEfficiencyConfig

from pyVmomi.vim.vsan.host import AddStoragePoolDiskSpec
from pyVmomi.vim.vsan.host import CreateNativeKeyProviderSpec
from pyVmomi.vim.vsan.host import DiskMappingCreationSpec
from pyVmomi.vim.vsan.host import EncryptionInfo

class VsanPrepareVsanForVcsaSpec(DynamicData):
   vsanDiskMappingCreationSpec: Optional[DiskMappingCreationSpec] = None
   vsanDataEfficiencyConfig: Optional[DataEfficiencyConfig] = None
   taskId: Optional[str] = None
   vsanDataEncryptionConfig: Optional[EncryptionInfo] = None
   vsanAddStoragePoolDiskSpec: Optional[AddStoragePoolDiskSpec] = None
   createNativeKeyProviderSpec: Optional[CreateNativeKeyProviderSpec] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class DhcpService(DynamicData):
   class Specification(DynamicData):
      virtualSwitch: str
      defaultLeaseDuration: int
      leaseBeginIp: str
      leaseEndIp: str
      maxLeaseDuration: int
      unlimitedLease: bool
      ipSubnetAddr: str
      ipSubnetMask: str

   class Config(DynamicData):
      changeOperation: Optional[str] = None
      key: str
      spec: Specification

   key: str
   spec: Specification



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .DhcpConfigInfo import DhcpConfigInfo as DhcpConfigInfo
from .DhcpConfigSpec import DhcpConfigSpec as DhcpConfigSpec
from .DnsConfigInfo import DnsConfigInfo as DnsConfigInfo
from .DnsConfigSpec import DnsConfigSpec as DnsConfigSpec
from .IpConfigInfo import IpConfigInfo as IpConfigInfo
from .IpConfigSpec import IpConfigSpec as IpConfigSpec
from .IpRouteConfigInfo import IpRouteConfigInfo as IpRouteConfigInfo
from .IpRouteConfigSpec import IpRouteConfigSpec as IpRouteConfigSpec
from .IpStackInfo import IpStackInfo as IpStackInfo
from .NetBIOSConfigInfo import NetBIOSConfigInfo as NetBIOSConfigInfo
from .WinNetBIOSConfigInfo import WinNetBIOSConfigInfo as WinNetBIOSConfigInfo



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import PerformanceManager

from pyVmomi.vim.alarm import AlarmExpression

class MetricAlarmExpression(AlarmExpression):
   class MetricOperator(Enum):
      isAbove: ClassVar['MetricOperator'] = 'isAbove'
      isBelow: ClassVar['MetricOperator'] = 'isBelow'

   operator: MetricOperator
   type: type
   metric: PerformanceManager.MetricId
   yellow: Optional[int] = None
   yellowInterval: Optional[int] = None
   red: Optional[int] = None
   redInterval: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.cluster import VsanIscsiLUNCommonInfo
from pyVmomi.vim.cluster import VsanObjectInformation

class VsanIscsiLUN(VsanIscsiLUNCommonInfo):
   targetAlias: str
   uuid: str
   actualSize: long
   objectInformation: Optional[VsanObjectInformation] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.vm import TargetInfo

class VgpuDeviceInfo(TargetInfo):
   deviceName: str
   deviceVendorId: long
   maxFbSizeInGib: long
   timeSlicedCapable: bool
   migCapable: bool
   computeProfileCapable: bool
   quadroProfileCapable: bool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import LocalizableMessage

from pyVmomi.vim.cluster import VsanClusterHealthSummary

from pyVmomi.vim.vsan import EntityResourceCheckDetails
from pyVmomi.vim.vsan import FaultDomainResourceCheckResult
from pyVmomi.vim.vsan import VsanHealthThreshold

class ResourceCheckResult(EntityResourceCheckDetails):
   class ResourceCheckDedupStoreHealthState(Enum):
      Inaccessible: ClassVar['ResourceCheckDedupStoreHealthState'] = 'Inaccessible'
      Noncompliant: ClassVar['ResourceCheckDedupStoreHealthState'] = 'Noncompliant'

   timestamp: datetime
   status: str
   messages: list[LocalizableMessage] = []
   faultDomains: list[FaultDomainResourceCheckResult] = []
   dataToMove: Optional[long] = None
   nonCompliantObjects: list[str] = []
   inaccessibleObjects: list[str] = []
   capacityThreshold: Optional[VsanHealthThreshold] = None
   health: Optional[VsanClusterHealthSummary] = None
   dataToResync: Optional[long] = None
   dedupStoreHealth: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanObjectOverallHealth

class VsanFileServiceShareHealthSummary(DynamicData):
   overallHealth: Optional[str] = None
   domainName: Optional[str] = None
   shareUuid: Optional[str] = None
   shareName: Optional[str] = None
   objectHealth: Optional[VsanObjectOverallHealth] = None
   description: Optional[str] = None
   extensible: Optional[bool] = None
   spbmProfileUuid: Optional[str] = None
   spbmProfileGenerationId: Optional[str] = None
   sharePolicyMismatch: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ElementDescription

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import Fru

class HardwareStatusInfo(DynamicData):
   class Status(Enum):
      Unknown: ClassVar['Status'] = 'Unknown'
      Green: ClassVar['Status'] = 'Green'
      Yellow: ClassVar['Status'] = 'Yellow'
      Red: ClassVar['Status'] = 'Red'

   class HardwareElementInfo(DynamicData):
      name: str
      status: ElementDescription

   class StorageStatusInfo(HardwareElementInfo):
      class OperationalInfo(DynamicData):
         property: str
         value: str

      operationalInfo: list[OperationalInfo] = []

   class DpuStatusInfo(HardwareElementInfo):
      class OperationalInfo(DynamicData):
         sensorId: str
         healthState: Optional[ElementDescription] = None
         reading: str
         units: Optional[str] = None
         timeStamp: Optional[datetime] = None

      dpuId: str
      fru: Optional[Fru] = None
      sensors: list[OperationalInfo] = []

   memoryStatusInfo: list[HardwareElementInfo] = []
   cpuStatusInfo: list[HardwareElementInfo] = []
   storageStatusInfo: list[StorageStatusInfo] = []
   dpuStatusInfo: list[DpuStatusInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import Snapshot

class FileLayoutEx(DynamicData):
   class FileType(Enum):
      config: ClassVar['FileType'] = 'config'
      extendedConfig: ClassVar['FileType'] = 'extendedConfig'
      diskDescriptor: ClassVar['FileType'] = 'diskDescriptor'
      diskExtent: ClassVar['FileType'] = 'diskExtent'
      digestDescriptor: ClassVar['FileType'] = 'digestDescriptor'
      digestExtent: ClassVar['FileType'] = 'digestExtent'
      diskReplicationState: ClassVar['FileType'] = 'diskReplicationState'
      log: ClassVar['FileType'] = 'log'
      stat: ClassVar['FileType'] = 'stat'
      namespaceData: ClassVar['FileType'] = 'namespaceData'
      dataSetsDiskModeStore: ClassVar['FileType'] = 'dataSetsDiskModeStore'
      dataSetsVmModeStore: ClassVar['FileType'] = 'dataSetsVmModeStore'
      nvram: ClassVar['FileType'] = 'nvram'
      snapshotData: ClassVar['FileType'] = 'snapshotData'
      snapshotMemory: ClassVar['FileType'] = 'snapshotMemory'
      snapshotList: ClassVar['FileType'] = 'snapshotList'
      snapshotManifestList: ClassVar['FileType'] = 'snapshotManifestList'
      suspend: ClassVar['FileType'] = 'suspend'
      suspendMemory: ClassVar['FileType'] = 'suspendMemory'
      swap: ClassVar['FileType'] = 'swap'
      uwswap: ClassVar['FileType'] = 'uwswap'
      core: ClassVar['FileType'] = 'core'
      screenshot: ClassVar['FileType'] = 'screenshot'
      ftMetadata: ClassVar['FileType'] = 'ftMetadata'
      guestCustomization: ClassVar['FileType'] = 'guestCustomization'

   class FileInfo(DynamicData):
      key: int
      name: str
      type: str
      size: long
      uniqueSize: Optional[long] = None
      backingObjectId: Optional[str] = None
      accessible: Optional[bool] = None

   class DiskUnit(DynamicData):
      fileKey: list[int] = []

   class DiskLayout(DynamicData):
      key: int
      virtualDiskFormat: Optional[str] = None
      chain: list[DiskUnit] = []

   class SnapshotLayout(DynamicData):
      key: Snapshot
      dataKey: int
      memoryKey: int
      disk: list[DiskLayout] = []

   file: list[FileInfo] = []
   disk: list[DiskLayout] = []
   snapshot: list[SnapshotLayout] = []
   timestamp: datetime



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualHardware(DynamicData):
   class MotherboardLayout(Enum):
      i440bxHostBridge: ClassVar['MotherboardLayout'] = 'i440bxHostBridge'
      acpiHostBridges: ClassVar['MotherboardLayout'] = 'acpiHostBridges'

   numCPU: int
   numCoresPerSocket: Optional[int] = None
   autoCoresPerSocket: Optional[bool] = None
   memoryMB: int
   virtualICH7MPresent: Optional[bool] = None
   virtualSMCPresent: Optional[bool] = None
   device: list[VirtualDevice] = []
   motherboardLayout: Optional[str] = None
   simultaneousThreads: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import VsanMassCollectorPropertyParams
from pyVmomi.vim import VsanResourceConstraint

from pyVmomi.vmodl import DynamicData

class VsanMassCollectorSpec(DynamicData):
   objects: list[ManagedObject] = []
   objectCollection: Optional[str] = None
   properties: list[str] = []
   propertiesParams: list[VsanMassCollectorPropertyParams] = []
   constraint: Optional[VsanResourceConstraint] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class NvmeTransportParameters(DynamicData):
   class NvmeAddressFamily(Enum):
      ipv4: ClassVar['NvmeAddressFamily'] = 'ipv4'
      ipv6: ClassVar['NvmeAddressFamily'] = 'ipv6'
      infiniBand: ClassVar['NvmeAddressFamily'] = 'infiniBand'
      fc: ClassVar['NvmeAddressFamily'] = 'fc'
      loopback: ClassVar['NvmeAddressFamily'] = 'loopback'
      unknown: ClassVar['NvmeAddressFamily'] = 'unknown'



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import VsanMassCollectorSpec

from pyVmomi.vmodl.query import PropertyCollector

class VsanMassCollector(ManagedObject):
   def VsanRetrieveProperties(self, massCollectorSpecs: list[VsanMassCollectorSpec]) -> list[PropertyCollector.ObjectContent]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedMethod

from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Task
from pyVmomi.vim import TaskReason

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import KeyAnyValue
from pyVmomi.vmodl import LocalizableMessage
from pyVmomi.vmodl import MethodFault

class TaskInfo(DynamicData):
   class State(Enum):
      queued: ClassVar['State'] = 'queued'
      running: ClassVar['State'] = 'running'
      success: ClassVar['State'] = 'success'
      error: ClassVar['State'] = 'error'

   key: str
   task: Task
   description: Optional[LocalizableMessage] = None
   name: Optional[ManagedMethod] = None
   descriptionId: str
   entity: Optional[ManagedEntity] = None
   entityName: Optional[str] = None
   locked: list[ManagedEntity] = []
   state: State
   cancelled: bool
   cancelable: bool
   error: Optional[MethodFault] = None
   result: Optional[object] = None
   progress: Optional[int] = None
   progressDetails: list[KeyAnyValue] = []
   reason: TaskReason
   queueTime: datetime
   startTime: Optional[datetime] = None
   completeTime: Optional[datetime] = None
   eventChainId: int
   changeTag: Optional[str] = None
   parentTaskKey: Optional[str] = None
   rootTaskKey: Optional[str] = None
   activationId: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class VVolVmConfigFileUpdateResult(DynamicData):
   class FailedVmConfigFileInfo(DynamicData):
      targetConfigVVolId: str
      dsPath: Optional[str] = None
      fault: MethodFault

   succeededVmConfigFile: list[KeyValue] = []
   failedVmConfigFile: list[FailedVmConfigFileInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.sms.storage.replication import GroupOperationResult
from pyVmomi.sms.storage.replication import PointInTimeReplicaId

class QueryPointInTimeReplicaSuccessResult(GroupOperationResult):
   class PointInTimeReplicaInfo(DynamicData):
      id: PointInTimeReplicaId
      pitName: str
      timeStamp: datetime
      tags: list[str] = []

   replicaInfo: list[PointInTimeReplicaInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import ScsiDisk

class VsanHostDiskMapping(DynamicData):
   class VsanDiskGroupCreationType(Enum):
      allflash: ClassVar['VsanDiskGroupCreationType'] = 'allflash'
      hybrid: ClassVar['VsanDiskGroupCreationType'] = 'hybrid'
      vsandirect: ClassVar['VsanDiskGroupCreationType'] = 'vsandirect'
      pmem: ClassVar['VsanDiskGroupCreationType'] = 'pmem'
      VsanDiskGroupCreationType_Unknown: ClassVar['VsanDiskGroupCreationType'] = 'VsanDiskGroupCreationType_Unknown'

   host: HostSystem
   cacheDisks: list[ScsiDisk] = []
   capacityDisks: list[ScsiDisk] = []
   type: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim.host import AuthenticationManagerInfo
from pyVmomi.vim.host import AuthenticationStore

class AuthenticationManager(ManagedObject):
   @property
   def info(self) -> AuthenticationManagerInfo: ...
   @property
   def supportedStore(self) -> list[AuthenticationStore]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ComputeResource

from pyVmomi.vim.cluster import CryptoConfigInfo
from pyVmomi.vim.cluster import DasConfigInfo
from pyVmomi.vim.cluster import DasVmConfigSpec
from pyVmomi.vim.cluster import DpmConfigInfo
from pyVmomi.vim.cluster import DpmHostConfigSpec
from pyVmomi.vim.cluster import DrsConfigInfo
from pyVmomi.vim.cluster import DrsVmConfigSpec
from pyVmomi.vim.cluster import GroupSpec
from pyVmomi.vim.cluster import InfraUpdateHaConfigInfo
from pyVmomi.vim.cluster import OrchestrationInfo
from pyVmomi.vim.cluster import ProactiveDrsConfigInfo
from pyVmomi.vim.cluster import RuleSpec
from pyVmomi.vim.cluster import SystemVMsConfigSpec
from pyVmomi.vim.cluster import VmOrchestrationSpec

from pyVmomi.vim.vsan.cluster import ConfigInfo
from pyVmomi.vim.vsan.cluster import CoreConfigSpec

from pyVmomi.vim.vsan.host import ConfigInfo

class ConfigSpecEx(ComputeResource.ConfigSpec):
   systemVMsConfig: Optional[SystemVMsConfigSpec] = None
   dasConfig: Optional[DasConfigInfo] = None
   dasVmConfigSpec: list[DasVmConfigSpec] = []
   drsConfig: Optional[DrsConfigInfo] = None
   drsVmConfigSpec: list[DrsVmConfigSpec] = []
   rulesSpec: list[RuleSpec] = []
   orchestration: Optional[OrchestrationInfo] = None
   vmOrchestrationSpec: list[VmOrchestrationSpec] = []
   dpmConfig: Optional[DpmConfigInfo] = None
   dpmHostConfigSpec: list[DpmHostConfigSpec] = []
   vsanConfig: Optional[ConfigInfo] = None
   vsanHostConfigSpec: list[ConfigInfo] = []
   groupSpec: list[GroupSpec] = []
   infraUpdateHaConfig: Optional[InfraUpdateHaConfigInfo] = None
   proactiveDrsConfig: Optional[ProactiveDrsConfigInfo] = None
   inHciWorkflow: Optional[bool] = None
   cryptoConfig: Optional[CryptoConfigInfo] = None
   vsanCoreConfigSpec: Optional[CoreConfigSpec] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class VStorageObjectQuerySpec(DynamicData):
   class QueryOperatorEnum(Enum):
      equals: ClassVar['QueryOperatorEnum'] = 'equals'
      notEquals: ClassVar['QueryOperatorEnum'] = 'notEquals'
      lessThan: ClassVar['QueryOperatorEnum'] = 'lessThan'
      greaterThan: ClassVar['QueryOperatorEnum'] = 'greaterThan'
      lessThanOrEqual: ClassVar['QueryOperatorEnum'] = 'lessThanOrEqual'
      greaterThanOrEqual: ClassVar['QueryOperatorEnum'] = 'greaterThanOrEqual'
      contains: ClassVar['QueryOperatorEnum'] = 'contains'
      startsWith: ClassVar['QueryOperatorEnum'] = 'startsWith'
      endsWith: ClassVar['QueryOperatorEnum'] = 'endsWith'

   class QueryFieldEnum(Enum):
      id: ClassVar['QueryFieldEnum'] = 'id'
      name: ClassVar['QueryFieldEnum'] = 'name'
      capacity: ClassVar['QueryFieldEnum'] = 'capacity'
      createTime: ClassVar['QueryFieldEnum'] = 'createTime'
      backingObjectId: ClassVar['QueryFieldEnum'] = 'backingObjectId'
      datastoreMoId: ClassVar['QueryFieldEnum'] = 'datastoreMoId'
      metadataKey: ClassVar['QueryFieldEnum'] = 'metadataKey'
      metadataValue: ClassVar['QueryFieldEnum'] = 'metadataValue'

   queryField: str
   queryOperator: str
   queryValue: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ExtendedElementDescription

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.profile import ProfilePropertyPath

class ParameterMetadata(DynamicData):
   class RelationType(Enum):
      dynamic_relation: ClassVar['RelationType'] = 'dynamic_relation'
      extensible_relation: ClassVar['RelationType'] = 'extensible_relation'
      localizable_relation: ClassVar['RelationType'] = 'localizable_relation'
      static_relation: ClassVar['RelationType'] = 'static_relation'
      validation_relation: ClassVar['RelationType'] = 'validation_relation'

   class ParameterRelationMetadata(DynamicData):
      relationTypes: list[str] = []
      values: list[object] = []
      path: Optional[ProfilePropertyPath] = None
      minCount: int
      maxCount: int

   id: ExtendedElementDescription
   type: type
   optional: bool
   defaultValue: Optional[object] = None
   hidden: Optional[bool] = None
   securitySensitive: Optional[bool] = None
   readOnly: Optional[bool] = None
   parameterRelations: list[ParameterRelationMetadata] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

class HostAccessManager(ManagedObject):
   class AccessMode(Enum):
      accessNone: ClassVar['AccessMode'] = 'accessNone'
      accessAdmin: ClassVar['AccessMode'] = 'accessAdmin'
      accessNoAccess: ClassVar['AccessMode'] = 'accessNoAccess'
      accessReadOnly: ClassVar['AccessMode'] = 'accessReadOnly'
      accessOther: ClassVar['AccessMode'] = 'accessOther'

   class AccessEntry(DynamicData):
      principal: str
      group: bool
      accessMode: AccessMode

   class LockdownMode(Enum):
      lockdownDisabled: ClassVar['LockdownMode'] = 'lockdownDisabled'
      lockdownNormal: ClassVar['LockdownMode'] = 'lockdownNormal'
      lockdownStrict: ClassVar['LockdownMode'] = 'lockdownStrict'

   @property
   def lockdownMode(self) -> LockdownMode: ...

   def RetrieveAccessEntries(self) -> list[AccessEntry]: ...
   def ChangeAccessMode(self, principal: str, isGroup: bool, accessMode: AccessMode) -> NoReturn: ...
   def QuerySystemUsers(self) -> list[str]: ...
   def UpdateSystemUsers(self, users: list[str]) -> NoReturn: ...
   def QueryLockdownExceptions(self) -> list[str]: ...
   def UpdateLockdownExceptions(self, users: list[str]) -> NoReturn: ...
   def ChangeLockdownMode(self, mode: LockdownMode) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import binary

from pyVmomi.vim.host import NvmeTransportParameters

class NvmeOpaqueTransportParameters(NvmeTransportParameters):
   trtype: str
   traddr: str
   adrfam: str
   trsvcid: str
   tsas: binary



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import FileSystemVolume
from pyVmomi.vim.host import ForceMountedInfo
from pyVmomi.vim.host import ScsiDisk

from pyVmomi.vim.option import LongOption

class VmfsVolume(FileSystemVolume):
   class Specification(DynamicData):
      extent: ScsiDisk.Partition
      blockSizeMb: Optional[int] = None
      majorVersion: int
      volumeName: str
      blockSize: Optional[int] = None
      unmapGranularity: Optional[int] = None
      unmapPriority: Optional[str] = None
      unmapBandwidthSpec: Optional[UnmapBandwidthSpec] = None

   class UnmapBandwidthSpec(DynamicData):
      policy: str
      fixedValue: long
      dynamicMin: long
      dynamicMax: long

   class UnmapPriority(Enum):
      none: ClassVar['UnmapPriority'] = 'none'
      low: ClassVar['UnmapPriority'] = 'low'

   class UnmapBandwidthPolicy(Enum):
      fixed: ClassVar['UnmapBandwidthPolicy'] = 'fixed'
      dynamic: ClassVar['UnmapBandwidthPolicy'] = 'dynamic'

   class ConfigOption(DynamicData):
      blockSizeOption: int
      unmapGranularityOption: list[int] = []
      unmapBandwidthFixedValue: Optional[LongOption] = None
      unmapBandwidthDynamicMin: Optional[LongOption] = None
      unmapBandwidthDynamicMax: Optional[LongOption] = None
      unmapBandwidthIncrement: Optional[long] = None
      unmapBandwidthUltraLow: Optional[long] = None

   blockSizeMb: int
   blockSize: Optional[int] = None
   unmapGranularity: Optional[int] = None
   unmapPriority: Optional[str] = None
   unmapBandwidthSpec: Optional[UnmapBandwidthSpec] = None
   maxBlocks: int
   majorVersion: int
   version: str
   uuid: str
   extent: list[ScsiDisk.Partition] = []
   vmfsUpgradable: bool
   forceMountedInfo: Optional[ForceMountedInfo] = None
   ssd: Optional[bool] = None
   local: Optional[bool] = None
   scsiDiskType: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Datastore
from pyVmomi.vim import Folder
from pyVmomi.vim import HostSystem
from pyVmomi.vim import KeyValue
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Network
from pyVmomi.vim import ResourceConfigSpec
from pyVmomi.vim import ResourcePool

from pyVmomi.vmodl import DynamicData

class CloneSpec(DynamicData):
   class NetworkMappingPair(DynamicData):
      source: Network
      destination: Network

   class ResourceMap(DynamicData):
      source: ManagedEntity
      parent: Optional[ResourcePool] = None
      resourceSpec: Optional[ResourceConfigSpec] = None
      location: Optional[Datastore] = None

   class ProvisioningType(Enum):
      sameAsSource: ClassVar['ProvisioningType'] = 'sameAsSource'
      thin: ClassVar['ProvisioningType'] = 'thin'
      thick: ClassVar['ProvisioningType'] = 'thick'

   location: Datastore
   host: Optional[HostSystem] = None
   resourceSpec: Optional[ResourceConfigSpec] = None
   vmFolder: Optional[Folder] = None
   networkMapping: list[NetworkMappingPair] = []
   property: list[KeyValue] = []
   resourceMapping: list[ResourceMap] = []
   provisioning: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import byte

from pyVmomi.vim import CustomizationSpecInfo
from pyVmomi.vim import CustomizationSpecItem

class CustomizationSpecManager(ManagedObject):
   @property
   def info(self) -> list[CustomizationSpecInfo]: ...
   @property
   def encryptionKey(self) -> list[byte]: ...

   def Exists(self, name: str) -> bool: ...
   def Get(self, name: str) -> CustomizationSpecItem: ...
   def Create(self, item: CustomizationSpecItem) -> NoReturn: ...
   def Overwrite(self, item: CustomizationSpecItem) -> NoReturn: ...
   def Delete(self, name: str) -> NoReturn: ...
   def Duplicate(self, name: str, newName: str) -> NoReturn: ...
   def Rename(self, name: str, newName: str) -> NoReturn: ...
   def SpecItemToXml(self, item: CustomizationSpecItem) -> str: ...
   def XmlToSpecItem(self, specItemXml: str) -> CustomizationSpecItem: ...
   def CheckResources(self, guestOs: str) -> NoReturn: ...
   def IsGuestOsCustomizable(self, guestId: str) -> bool: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DatastoreUpdateSpec
from pyVmomi.vim.cluster import TagCategoryUpdateSpec

class SystemVMsConfigSpec(DynamicData):
   allowedDatastores: list[DatastoreUpdateSpec] = []
   notAllowedDatastores: list[DatastoreUpdateSpec] = []
   dsTagCategoriesToExclude: list[TagCategoryUpdateSpec] = []
   deploymentMode: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import PrivilegePolicyDef

from pyVmomi.vmodl import DynamicData

class CustomFieldsManager(ManagedObject):
   class FieldDef(DynamicData):
      key: int
      name: str
      type: type
      managedObjectType: Optional[type] = None
      fieldDefPrivileges: Optional[PrivilegePolicyDef] = None
      fieldInstancePrivileges: Optional[PrivilegePolicyDef] = None

   class Value(DynamicData):
      key: int

   class StringValue(Value):
      value: str

   @property
   def field(self) -> list[FieldDef]: ...

   def AddFieldDefinition(self, name: str, moType: Optional[type], fieldDefPolicy: Optional[PrivilegePolicyDef], fieldPolicy: Optional[PrivilegePolicyDef]) -> FieldDef: ...
   def RemoveFieldDefinition(self, key: int) -> NoReturn: ...
   def RenameFieldDefinition(self, key: int, name: str) -> NoReturn: ...
   def SetField(self, entity: ManagedEntity, key: int, value: str) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import VimFault

class CannotMoveFaultToleranceVm(VimFault):
   class MoveType(Enum):
      resourcePool: ClassVar['MoveType'] = 'resourcePool'
      cluster: ClassVar['MoveType'] = 'cluster'

   moveType: str
   vmName: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class SystemSwapConfiguration(DynamicData):
   class SystemSwapOption(DynamicData):
      key: int

   class DisabledOption(SystemSwapOption):
      pass

   class HostCacheOption(SystemSwapOption):
      pass

   class HostLocalSwapOption(SystemSwapOption):
      pass

   class DatastoreOption(SystemSwapOption):
      datastore: str

   option: list[SystemSwapOption] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class FcoeConfig(DynamicData):
   class VlanRange(DynamicData):
      vlanLow: int
      vlanHigh: int

   class FcoeCapabilities(DynamicData):
      priorityClass: bool
      sourceMacAddress: bool
      vlanRange: bool

   class FcoeSpecification(DynamicData):
      underlyingPnic: str
      priorityClass: Optional[int] = None
      sourceMac: Optional[str] = None
      vlanRange: list[VlanRange] = []

   priorityClass: int
   sourceMac: str
   vlanRange: list[VlanRange] = []
   capabilities: FcoeCapabilities
   fcoeActive: bool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

class TrustAuthorityAttestationInfo(DynamicData):
   class AttestationStatus(Enum):
      attested: ClassVar['AttestationStatus'] = 'attested'
      notAttested: ClassVar['AttestationStatus'] = 'notAttested'
      unknown: ClassVar['AttestationStatus'] = 'unknown'

   attestationStatus: str
   serviceId: Optional[str] = None
   attestedAt: Optional[datetime] = None
   attestedUntil: Optional[datetime] = None
   messages: list[LocalizableMessage] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ComputeResource
from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

class VsanHclQuerySpec(DynamicData):
   includeOnlyVsanControllers: Optional[bool] = None
   cluster: Optional[ComputeResource] = None
   hosts: list[HostSystem] = []
   vsanStoragePoolEligibleDisksOnly: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanFileServerHealthSummary
from pyVmomi.vim.host import VsanFileServiceBalanceHealth
from pyVmomi.vim.host import VsanFileServiceRootFsHealth
from pyVmomi.vim.host import VsanFileServiceShareHealthSummary
from pyVmomi.vim.host import VsanResourceHealth

class VsanFileServiceHealthSummary(DynamicData):
   hostname: Optional[str] = None
   overallHealth: Optional[str] = None
   enabled: Optional[bool] = None
   vdfsdStatus: Optional[VsanResourceHealth] = None
   fsvmStatus: Optional[VsanResourceHealth] = None
   rootFsStatus: Optional[VsanFileServiceRootFsHealth] = None
   fileServerHealth: list[VsanFileServerHealthSummary] = []
   fileShareHealth: list[VsanFileServiceShareHealthSummary] = []
   balanceStatus: Optional[VsanFileServiceBalanceHealth] = None
   hostLoadStatus: Optional[VsanResourceHealth] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim.vm import TargetInfo
from pyVmomi.vim.vm import VMotionStunTimeInfo

class VgpuProfileInfo(TargetInfo):
   class ProfileSharing(Enum):
      timeSliced: ClassVar['ProfileSharing'] = 'timeSliced'
      mig: ClassVar['ProfileSharing'] = 'mig'

   class ProfileClass(Enum):
      compute: ClassVar['ProfileClass'] = 'compute'
      quadro: ClassVar['ProfileClass'] = 'quadro'

   profileName: str
   deviceVendorId: long
   fbSizeInGib: long
   profileSharing: str
   profileClass: str
   stunTimeEstimates: list[VMotionStunTimeInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanDownloadItem

class VsanHclDriverInfo(DynamicData):
   driverVersion: Optional[str] = None
   driverLink: Optional[VsanDownloadItem] = None
   fwVersion: Optional[str] = None
   fwLinks: list[VsanDownloadItem] = []
   toolsLinks: list[VsanDownloadItem] = []
   eula: Optional[str] = None
   driverType: Optional[str] = None
   driverName: Optional[str] = None
   diskModes: list[str] = []
   supportedFeatures: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.fault import InvalidState

class CannotPowerOffVmInCluster(InvalidState):
   class Operation(Enum):
      suspend: ClassVar['Operation'] = 'suspend'
      powerOff: ClassVar['Operation'] = 'powerOff'
      guestShutdown: ClassVar['Operation'] = 'guestShutdown'
      guestSuspend: ClassVar['Operation'] = 'guestSuspend'

   operation: str
   vm: VirtualMachine
   vmName: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.cluster import VsanPerfMasterInformation

class VsanPerfNodeInformation(DynamicData):
   version: str
   hostname: Optional[str] = None
   error: Optional[MethodFault] = None
   isCmmdsMaster: bool
   isStatsMaster: bool
   vsanMasterUuid: Optional[str] = None
   vsanNodeUuid: Optional[str] = None
   masterInfo: Optional[VsanPerfMasterInformation] = None
   diagnosticMode: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ServiceManager

class SimpleCommand(ManagedObject):
   class Encoding(Enum):
      CSV: ClassVar['Encoding'] = 'CSV'
      HEX: ClassVar['Encoding'] = 'HEX'
      STRING: ClassVar['Encoding'] = 'STRING'

   @property
   def encodingType(self) -> Encoding: ...
   @property
   def entity(self) -> ServiceManager.ServiceInfo: ...

   def Execute(self, arguments: list[str]) -> str: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import UserSearchResult

class UserDirectory(ManagedObject):
   @property
   def domainList(self) -> list[str]: ...

   def RetrieveUserGroups(self, domain: Optional[str], searchStr: str, belongsToGroup: Optional[str], belongsToUser: Optional[str], exactMatch: bool, findUsers: bool, findGroups: bool) -> list[UserSearchResult]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import binary

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

class EntityBackup(DynamicData):
   class Config(DynamicData):
      entityType: str
      configBlob: binary
      key: Optional[str] = None
      name: Optional[str] = None
      container: Optional[ManagedEntity] = None
      configVersion: Optional[str] = None

   class EntityType(Enum):
      distributedVirtualSwitch: ClassVar['EntityType'] = 'distributedVirtualSwitch'
      distributedVirtualPortgroup: ClassVar['EntityType'] = 'distributedVirtualPortgroup'

   class ImportType(Enum):
      createEntityWithNewIdentifier: ClassVar['ImportType'] = 'createEntityWithNewIdentifier'
      createEntityWithOriginalIdentifier: ClassVar['ImportType'] = 'createEntityWithOriginalIdentifier'
      applyToEntitySpecified: ClassVar['ImportType'] = 'applyToEntitySpecified'



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.sms import AboutInfo
from pyVmomi.sms import StorageManager

from pyVmomi.sms.auth import SessionManager

class ServiceInstance(ManagedObject):
   def QueryStorageManager(self) -> StorageManager: ...
   def QuerySessionManager(self) -> SessionManager: ...
   def QueryAboutInfo(self) -> AboutInfo: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import MigrationFault

class WillLoseHAProtection(MigrationFault):
   class Resolution(Enum):
      svmotion: ClassVar['Resolution'] = 'svmotion'
      relocate: ClassVar['Resolution'] = 'relocate'

   resolution: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import binary
from pyVmomi.VmomiSupport import byte

from pyVmomi.vim import AboutInfo
from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem
from pyVmomi.vim import IoFilterManager

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import AssignableHardwareBinding
from pyVmomi.vim.host import AssignableHardwareConfig
from pyVmomi.vim.host import AuthenticationInfo
from pyVmomi.vim.host import AuthenticationManagerInfo
from pyVmomi.vim.host import AutoStartManager
from pyVmomi.vim.host import CacheConfigurationManager
from pyVmomi.vim.host import CpuSchedulerSystem
from pyVmomi.vim.host import DatastoreSystem
from pyVmomi.vim.host import DateTimeInfo
from pyVmomi.vim.host import DeploymentInfo
from pyVmomi.vim.host import DiagnosticPartition
from pyVmomi.vim.host import FeatureCapability
from pyVmomi.vim.host import FeatureVersionInfo
from pyVmomi.vim.host import FileSystemVolumeInfo
from pyVmomi.vim.host import FirewallInfo
from pyVmomi.vim.host import FlagInfo
from pyVmomi.vim.host import GraphicsConfig
from pyVmomi.vim.host import GraphicsInfo
from pyVmomi.vim.host import HostAccessManager
from pyVmomi.vim.host import IpmiInfo
from pyVmomi.vim.host import MemoryManagerSystem
from pyVmomi.vim.host import MultipathStateInfo
from pyVmomi.vim.host import NetCapabilities
from pyVmomi.vim.host import NetOffloadCapabilities
from pyVmomi.vim.host import NetworkInfo
from pyVmomi.vim.host import PciPassthruInfo
from pyVmomi.vim.host import PowerSystem
from pyVmomi.vim.host import ServiceInfo
from pyVmomi.vim.host import SharedGpuCapabilities
from pyVmomi.vim.host import SriovDevicePoolInfo
from pyVmomi.vim.host import SslThumbprintInfo
from pyVmomi.vim.host import StorageDeviceInfo
from pyVmomi.vim.host import SystemResourceInfo
from pyVmomi.vim.host import SystemSwapConfiguration
from pyVmomi.vim.host import VFlashManager
from pyVmomi.vim.host import VMotionInfo
from pyVmomi.vim.host import VirtualNicManagerInfo

from pyVmomi.vim.option import OptionDef
from pyVmomi.vim.option import OptionValue

class ConfigInfo(DynamicData):
   host: HostSystem
   product: AboutInfo
   deploymentInfo: Optional[DeploymentInfo] = None
   hyperThread: Optional[CpuSchedulerSystem.HyperThreadScheduleInfo] = None
   cpuScheduler: Optional[CpuSchedulerSystem.CpuSchedulerInfo] = None
   consoleReservation: Optional[MemoryManagerSystem.ServiceConsoleReservationInfo] = None
   virtualMachineReservation: Optional[MemoryManagerSystem.VirtualMachineReservationInfo] = None
   storageDevice: Optional[StorageDeviceInfo] = None
   multipathState: Optional[MultipathStateInfo] = None
   fileSystemVolume: Optional[FileSystemVolumeInfo] = None
   systemFile: list[str] = []
   network: Optional[NetworkInfo] = None
   vmotion: Optional[VMotionInfo] = None
   virtualNicManagerInfo: Optional[VirtualNicManagerInfo] = None
   capabilities: Optional[NetCapabilities] = None
   datastoreCapabilities: Optional[DatastoreSystem.Capabilities] = None
   offloadCapabilities: Optional[NetOffloadCapabilities] = None
   service: Optional[ServiceInfo] = None
   firewall: Optional[FirewallInfo] = None
   autoStart: Optional[AutoStartManager.Config] = None
   activeDiagnosticPartition: Optional[DiagnosticPartition] = None
   option: list[OptionValue] = []
   optionDef: list[OptionDef] = []
   datastorePrincipal: Optional[str] = None
   localSwapDatastore: Optional[Datastore] = None
   systemSwapConfiguration: Optional[SystemSwapConfiguration] = None
   systemResources: Optional[SystemResourceInfo] = None
   dateTimeInfo: Optional[DateTimeInfo] = None
   flags: Optional[FlagInfo] = None
   adminDisabled: Optional[bool] = None
   lockdownMode: Optional[HostAccessManager.LockdownMode] = None
   ipmi: Optional[IpmiInfo] = None
   sslThumbprintInfo: Optional[SslThumbprintInfo] = None
   sslThumbprintData: list[SslThumbprintInfo] = []
   authenticationData: list[AuthenticationInfo] = []
   certificate: list[byte] = []
   pciPassthruInfo: list[PciPassthruInfo] = []
   authenticationManagerInfo: Optional[AuthenticationManagerInfo] = None
   featureVersion: list[FeatureVersionInfo] = []
   powerSystemCapability: Optional[PowerSystem.Capability] = None
   powerSystemInfo: Optional[PowerSystem.Info] = None
   cacheConfigurationInfo: list[CacheConfigurationManager.CacheConfigurationInfo] = []
   wakeOnLanCapable: Optional[bool] = None
   featureCapability: list[FeatureCapability] = []
   maskedFeatureCapability: list[FeatureCapability] = []
   vFlashConfigInfo: Optional[VFlashManager.VFlashConfigInfo] = None
   vsanHostConfig: Optional[ConfigInfo] = None
   domainList: list[str] = []
   scriptCheckSum: Optional[binary] = None
   hostConfigCheckSum: Optional[binary] = None
   descriptionTreeCheckSum: Optional[binary] = None
   graphicsInfo: list[GraphicsInfo] = []
   sharedPassthruGpuTypes: list[str] = []
   graphicsConfig: Optional[GraphicsConfig] = None
   sharedGpuCapabilities: list[SharedGpuCapabilities] = []
   ioFilterInfo: list[IoFilterManager.HostIoFilterInfo] = []
   sriovDevicePool: list[SriovDevicePoolInfo] = []
   assignableHardwareBinding: list[AssignableHardwareBinding] = []
   assignableHardwareConfig: Optional[AssignableHardwareConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DhcpService
from pyVmomi.vim.host import DnsConfig
from pyVmomi.vim.host import HostProxySwitch
from pyVmomi.vim.host import IpRouteConfig
from pyVmomi.vim.host import IpRouteTableConfig
from pyVmomi.vim.host import NatService
from pyVmomi.vim.host import NetStackInstance
from pyVmomi.vim.host import PhysicalNic
from pyVmomi.vim.host import PortGroup
from pyVmomi.vim.host import VirtualNic
from pyVmomi.vim.host import VirtualSwitch

class NetworkConfig(DynamicData):
   class Result(DynamicData):
      vnicDevice: list[str] = []
      consoleVnicDevice: list[str] = []

   class NetStackSpec(DynamicData):
      netStackInstance: NetStackInstance
      operation: Optional[str] = None

   vswitch: list[VirtualSwitch.Config] = []
   proxySwitch: list[HostProxySwitch.Config] = []
   portgroup: list[PortGroup.Config] = []
   pnic: list[PhysicalNic.Config] = []
   vnic: list[VirtualNic.Config] = []
   consoleVnic: list[VirtualNic.Config] = []
   dnsConfig: Optional[DnsConfig] = None
   ipRouteConfig: Optional[IpRouteConfig] = None
   consoleIpRouteConfig: Optional[IpRouteConfig] = None
   routeTableConfig: Optional[IpRouteTableConfig] = None
   dhcp: list[DhcpService.Config] = []
   nat: list[NatService.Config] = []
   ipV6Enabled: Optional[bool] = None
   netStackSpec: list[NetStackSpec] = []
   migrationStatus: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Datacenter
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class FileManager(ManagedObject):
   class FileLockInfo(DynamicData):
      filePath: str
      host: str
      mac: str
      id: str
      worldName: str
      ownerId: Optional[str] = None
      lockMode: str
      acquired: Optional[datetime] = None
      heartbeat: Optional[datetime] = None
      refCount: Optional[int] = None

   class FileLockInfoResult(DynamicData):
      lockInfo: list[FileLockInfo] = []
      fault: Optional[MethodFault] = None

   def MoveFile(self, sourceName: str, sourceDatacenter: Optional[Datacenter], destinationName: str, destinationDatacenter: Optional[Datacenter], force: Optional[bool]) -> Task: ...
   def CopyFile(self, sourceName: str, sourceDatacenter: Optional[Datacenter], destinationName: str, destinationDatacenter: Optional[Datacenter], force: Optional[bool]) -> Task: ...
   def DeleteFile(self, name: str, datacenter: Optional[Datacenter]) -> Task: ...
   def MakeDirectory(self, name: str, datacenter: Optional[Datacenter], createParentDirectories: Optional[bool]) -> NoReturn: ...
   def ChangeOwner(self, name: str, datacenter: Optional[Datacenter], owner: str) -> NoReturn: ...
   def QueryFileLockInfo(self, path: str, host: Optional[HostSystem]) -> FileLockInfoResult: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import HostBusAdapter
from pyVmomi.vim.host import NvmeNamespace

class NvmeController(DynamicData):
   key: str
   controllerNumber: int
   subnqn: str
   name: str
   associatedAdapter: HostBusAdapter
   transportType: str
   fusedOperationSupported: bool
   numberOfQueues: int
   queueSize: int
   attachedNamespace: list[NvmeNamespace] = []
   vendorId: Optional[str] = None
   model: Optional[str] = None
   serialNumber: Optional[str] = None
   firmwareVersion: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import Task

from pyVmomi.vim.vsan import VsanCloudHealthStatus

class VsanPhoneHomeSystem(ManagedObject):
   def VsanPerformOnlineHealthCheck(self, cluster: ClusterComputeResource) -> Task: ...
   def QueryVsanCloudHealthStatus(self) -> Optional[VsanCloudHealthStatus]: ...
   def VsanQueryObjectSnapshotsInfo(self, cluster: ClusterComputeResource) -> Optional[str]: ...
   def VsanQueryNvmeCriticalWarningStats(self, cluster: ClusterComputeResource) -> Optional[str]: ...
   def VsanQueryZdomScrubberData(self, cluster: ClusterComputeResource) -> Optional[str]: ...
   def VsanQueryLSOMwbsize(self, cluster: ClusterComputeResource) -> Optional[str]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class FileSystemVolume(DynamicData):
   class FileSystemType(Enum):
      VMFS: ClassVar['FileSystemType'] = 'VMFS'
      NFS: ClassVar['FileSystemType'] = 'NFS'
      NFS41: ClassVar['FileSystemType'] = 'NFS41'
      CIFS: ClassVar['FileSystemType'] = 'CIFS'
      vsan: ClassVar['FileSystemType'] = 'vsan'
      VFFS: ClassVar['FileSystemType'] = 'VFFS'
      VVOL: ClassVar['FileSystemType'] = 'VVOL'
      PMEM: ClassVar['FileSystemType'] = 'PMEM'
      vsanD: ClassVar['FileSystemType'] = 'vsanD'
      OTHER: ClassVar['FileSystemType'] = 'OTHER'

   type: str
   name: str
   capacity: long



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Folder
from pyVmomi.vim import HostSystem
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.storageDrs import PodSelectionSpec

from pyVmomi.vim.vm import CloneSpec
from pyVmomi.vim.vm import ConfigSpec
from pyVmomi.vim.vm import RelocateSpec

class StoragePlacementSpec(DynamicData):
   class PlacementType(Enum):
      create: ClassVar['PlacementType'] = 'create'
      reconfigure: ClassVar['PlacementType'] = 'reconfigure'
      relocate: ClassVar['PlacementType'] = 'relocate'
      clone: ClassVar['PlacementType'] = 'clone'

   type: str
   priority: Optional[VirtualMachine.MovePriority] = None
   vm: Optional[VirtualMachine] = None
   podSelectionSpec: PodSelectionSpec
   cloneSpec: Optional[CloneSpec] = None
   cloneName: Optional[str] = None
   configSpec: Optional[ConfigSpec] = None
   relocateSpec: Optional[RelocateSpec] = None
   resourcePool: Optional[ResourcePool] = None
   host: Optional[HostSystem] = None
   folder: Optional[Folder] = None
   disallowPrerequisiteMoves: Optional[bool] = None
   resourceLeaseDurationSec: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.event import VmEvent

class VmDasBeingResetEvent(VmEvent):
   class ReasonCode(Enum):
      vmtoolsHeartbeatFailure: ClassVar['ReasonCode'] = 'vmtoolsHeartbeatFailure'
      appHeartbeatFailure: ClassVar['ReasonCode'] = 'appHeartbeatFailure'
      appImmediateResetRequest: ClassVar['ReasonCode'] = 'appImmediateResetRequest'
      vmcpResetApdCleared: ClassVar['ReasonCode'] = 'vmcpResetApdCleared'
      guestOsCrashFailure: ClassVar['ReasonCode'] = 'guestOsCrashFailure'

   reason: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DrsMigration

class DrsRecommendation(DynamicData):
   class ReasonCode(Enum):
      fairnessCpuAvg: ClassVar['ReasonCode'] = 'fairnessCpuAvg'
      fairnessMemAvg: ClassVar['ReasonCode'] = 'fairnessMemAvg'
      jointAffin: ClassVar['ReasonCode'] = 'jointAffin'
      antiAffin: ClassVar['ReasonCode'] = 'antiAffin'
      hostMaint: ClassVar['ReasonCode'] = 'hostMaint'

   key: str
   rating: int
   reason: str
   reasonText: str
   migrationList: list[DrsMigration] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class VsanVsanPcapResult(DynamicData):
   calltime: float
   vmknic: str
   tcpdumpFilter: str
   snaplen: int
   pkts: list[str] = []
   pcap: Optional[str] = None
   error: Optional[MethodFault] = None
   hostname: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.profile import CapabilityConstraints
from pyVmomi.pbm.profile import ResourceType

class CapabilityBasedProfileCreateSpec(DynamicData):
   name: str
   description: Optional[str] = None
   category: Optional[str] = None
   resourceType: ResourceType
   constraints: CapabilityConstraints



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.fault import ReplicationConfigFault

class ReplicationVmConfigFault(ReplicationConfigFault):
   class ReasonForFault(Enum):
      incompatibleHwVersion: ClassVar['ReasonForFault'] = 'incompatibleHwVersion'
      invalidVmReplicationId: ClassVar['ReasonForFault'] = 'invalidVmReplicationId'
      invalidGenerationNumber: ClassVar['ReasonForFault'] = 'invalidGenerationNumber'
      outOfBoundsRpoValue: ClassVar['ReasonForFault'] = 'outOfBoundsRpoValue'
      invalidDestinationIpAddress: ClassVar['ReasonForFault'] = 'invalidDestinationIpAddress'
      invalidDestinationPort: ClassVar['ReasonForFault'] = 'invalidDestinationPort'
      invalidExtraVmOptions: ClassVar['ReasonForFault'] = 'invalidExtraVmOptions'
      staleGenerationNumber: ClassVar['ReasonForFault'] = 'staleGenerationNumber'
      reconfigureVmReplicationIdNotAllowed: ClassVar['ReasonForFault'] = 'reconfigureVmReplicationIdNotAllowed'
      cannotRetrieveVmReplicationConfiguration: ClassVar['ReasonForFault'] = 'cannotRetrieveVmReplicationConfiguration'
      replicationAlreadyEnabled: ClassVar['ReasonForFault'] = 'replicationAlreadyEnabled'
      invalidPriorConfiguration: ClassVar['ReasonForFault'] = 'invalidPriorConfiguration'
      replicationNotEnabled: ClassVar['ReasonForFault'] = 'replicationNotEnabled'
      replicationConfigurationFailed: ClassVar['ReasonForFault'] = 'replicationConfigurationFailed'
      encryptedVm: ClassVar['ReasonForFault'] = 'encryptedVm'
      invalidThumbprint: ClassVar['ReasonForFault'] = 'invalidThumbprint'
      incompatibleDevice: ClassVar['ReasonForFault'] = 'incompatibleDevice'

   reason: Optional[str] = None
   vmRef: Optional[VirtualMachine] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import SgxRegistrationInfo

class SgxInfo(DynamicData):
   class SgxStates(Enum):
      notPresent: ClassVar['SgxStates'] = 'notPresent'
      disabledBIOS: ClassVar['SgxStates'] = 'disabledBIOS'
      disabledCFW101: ClassVar['SgxStates'] = 'disabledCFW101'
      disabledCPUMismatch: ClassVar['SgxStates'] = 'disabledCPUMismatch'
      disabledNoFLC: ClassVar['SgxStates'] = 'disabledNoFLC'
      disabledNUMAUnsup: ClassVar['SgxStates'] = 'disabledNUMAUnsup'
      disabledMaxEPCRegs: ClassVar['SgxStates'] = 'disabledMaxEPCRegs'
      enabled: ClassVar['SgxStates'] = 'enabled'

   class FlcModes(Enum):
      off: ClassVar['FlcModes'] = 'off'
      locked: ClassVar['FlcModes'] = 'locked'
      unlocked: ClassVar['FlcModes'] = 'unlocked'

   sgxState: str
   totalEpcMemory: long
   flcMode: str
   lePubKeyHash: Optional[str] = None
   registrationInfo: Optional[SgxRegistrationInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import StorageResourceManager

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import ChoiceOption
from pyVmomi.vim.option import LongOption

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualDiskOption(VirtualDeviceOption):
   class DiskMode(Enum):
      persistent: ClassVar['DiskMode'] = 'persistent'
      nonpersistent: ClassVar['DiskMode'] = 'nonpersistent'
      undoable: ClassVar['DiskMode'] = 'undoable'
      independent_persistent: ClassVar['DiskMode'] = 'independent_persistent'
      independent_nonpersistent: ClassVar['DiskMode'] = 'independent_nonpersistent'
      append: ClassVar['DiskMode'] = 'append'

   class CompatibilityMode(Enum):
      virtualMode: ClassVar['CompatibilityMode'] = 'virtualMode'
      physicalMode: ClassVar['CompatibilityMode'] = 'physicalMode'

   class SparseVer1BackingOption(VirtualDeviceOption.FileBackingOption):
      diskModes: ChoiceOption
      split: BoolOption
      writeThrough: BoolOption
      growable: bool

   class SparseVer2BackingOption(VirtualDeviceOption.FileBackingOption):
      diskMode: ChoiceOption
      split: BoolOption
      writeThrough: BoolOption
      growable: bool
      hotGrowable: bool
      uuid: bool
      virtualDiskFormat: Optional[ChoiceOption] = None

   class FlatVer1BackingOption(VirtualDeviceOption.FileBackingOption):
      diskMode: ChoiceOption
      split: BoolOption
      writeThrough: BoolOption
      growable: bool

   class DeltaDiskFormatsSupported(DynamicData):
      datastoreType: type
      deltaDiskFormat: ChoiceOption

   class FlatVer2BackingOption(VirtualDeviceOption.FileBackingOption):
      diskMode: ChoiceOption
      split: BoolOption
      writeThrough: BoolOption
      growable: bool
      hotGrowable: bool
      uuid: bool
      thinProvisioned: BoolOption
      eagerlyScrub: BoolOption
      deltaDiskFormat: ChoiceOption
      deltaDiskFormatsSupported: list[DeltaDiskFormatsSupported] = []
      virtualDiskFormat: Optional[ChoiceOption] = None

   class SeSparseBackingOption(VirtualDeviceOption.FileBackingOption):
      diskMode: ChoiceOption
      writeThrough: BoolOption
      growable: bool
      hotGrowable: bool
      uuid: bool
      deltaDiskFormatsSupported: list[DeltaDiskFormatsSupported] = []
      virtualDiskFormat: Optional[ChoiceOption] = None

   class RawDiskVer2BackingOption(VirtualDeviceOption.DeviceBackingOption):
      descriptorFileNameExtensions: ChoiceOption
      uuid: bool

   class PartitionedRawDiskVer2BackingOption(RawDiskVer2BackingOption):
      pass

   class RawDiskMappingVer1BackingOption(VirtualDeviceOption.DeviceBackingOption):
      descriptorFileNameExtensions: Optional[ChoiceOption] = None
      compatibilityMode: ChoiceOption
      diskMode: ChoiceOption
      uuid: bool
      virtualDiskFormat: Optional[ChoiceOption] = None

   class LocalPMemBackingOption(VirtualDeviceOption.FileBackingOption):
      diskMode: ChoiceOption
      growable: bool
      hotGrowable: bool
      uuid: bool

   class VFlashCacheConfigOption(DynamicData):
      cacheConsistencyType: ChoiceOption
      cacheMode: ChoiceOption
      reservationInMB: LongOption
      blockSizeInKB: LongOption

   capacityInKB: LongOption
   ioAllocationOption: StorageResourceManager.IOAllocationOption
   vFlashCacheConfigOption: Optional[VFlashCacheConfigOption] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.eam import Agency
from pyVmomi.eam import Agent

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import KeyAnyValue

from pyVmomi.eam.issue import Issue

class ExtensibleIssue(Issue):
   typeId: str
   argument: list[KeyAnyValue] = []
   target: Optional[ManagedEntity] = None
   agent: Optional[Agent] = None
   agency: Optional[Agency] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.dvs import HostMember

from pyVmomi.vim.event import HostEvent

class DvsHealthStatusChangeEvent(HostEvent):
   switchUuid: str
   healthResult: Optional[HostMember.HealthCheckResult] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import PortConnection

from pyVmomi.vim.host import IpConfig
from pyVmomi.vim.host import IpRouteConfig
from pyVmomi.vim.host import PortGroup

class VirtualNic(DynamicData):
   class Specification(DynamicData):
      ip: Optional[IpConfig] = None
      mac: Optional[str] = None
      distributedVirtualPort: Optional[PortConnection] = None
      portgroup: Optional[str] = None
      mtu: Optional[int] = None
      tsoEnabled: Optional[bool] = None
      netStackInstanceKey: Optional[str] = None
      opaqueNetwork: Optional[OpaqueNetworkSpec] = None
      externalId: Optional[str] = None
      pinnedPnic: Optional[str] = None
      ipRouteSpec: Optional[IpRouteSpec] = None
      systemOwned: Optional[bool] = None
      dpuId: Optional[str] = None

   class Config(DynamicData):
      changeOperation: Optional[str] = None
      device: Optional[str] = None
      portgroup: str
      spec: Optional[Specification] = None

   class OpaqueNetworkSpec(DynamicData):
      opaqueNetworkId: str
      opaqueNetworkType: str

   class IpRouteSpec(DynamicData):
      ipRouteConfig: Optional[IpRouteConfig] = None

   device: str
   key: str
   portgroup: str
   spec: Specification
   port: Optional[PortGroup.Port] = None
   owner: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class AssignableHardwareConfig(DynamicData):
   class AttributeOverride(DynamicData):
      instanceId: str
      name: str
      value: Optional[object] = None

   attributeOverride: list[AttributeOverride] = []



# Copyright (c) 2008-2024 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.

# Cache decorator implementation

def Cache(fn):
    """ Function cache decorator """
    def fnCache(*args, **kwargs):
        """ Cache function """
        key = (args and tuple(args)
               or None, kwargs and frozenset(list(kwargs.items())) or None)
        if key not in fn.__cached__:
            fn.__cached__[key] = cache = fn(*args, **kwargs)
        else:
            cache = fn.__cached__[key]
        return cache

    def ResetCache():
        """ Reset cache """
        fn.__cached__ = {}

    setattr(fn, "__cached__", {})
    setattr(fn, "__resetcache__", ResetCache)
    fnCache.__name__ = fn.__name__
    fnCache.__doc__ = fn.__doc__
    fnCache.__dict__.update(fn.__dict__)
    return fnCache



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.vim import ExtensibleManagedObject
from pyVmomi.vim import HostSystem
from pyVmomi.vim import HttpNfcLease
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.vm import ConfigInfo

class Snapshot(ExtensibleManagedObject):
   @property
   def config(self) -> ConfigInfo: ...
   @property
   def childSnapshot(self) -> list[Snapshot]: ...
   @property
   def vm(self) -> VirtualMachine: ...

   def Revert(self, host: Optional[HostSystem], suppressPowerOn: Optional[bool]) -> Task: ...
   def Remove(self, removeChildren: bool, consolidate: Optional[bool]) -> Task: ...
   def Rename(self, name: Optional[str], description: Optional[str]) -> NoReturn: ...
   def ExportSnapshot(self) -> HttpNfcLease: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class VsanPerfMasterInformation(DynamicData):
   secSinceLastStatsWrite: Optional[long] = None
   secSinceLastStatsCollect: Optional[long] = None
   statsIntervalSec: long
   collectionFailureHostUuids: list[str] = []
   renamedStatsDirectories: list[str] = []
   statsDirectoryPercentFree: Optional[long] = None
   verboseMode: Optional[bool] = None
   verboseModeLastUpdate: Optional[datetime] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class TargetInfo(DynamicData):
   class ConfigurationTag(Enum):
      compliant: ClassVar['ConfigurationTag'] = 'compliant'
      clusterWide: ClassVar['ConfigurationTag'] = 'clusterWide'

   name: str
   configurationTag: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class LoggingConfiguration(DynamicData):
   class Component(Enum):
      pbm: ClassVar['Component'] = 'pbm'
      vslm: ClassVar['Component'] = 'vslm'
      sms: ClassVar['Component'] = 'sms'
      spbm: ClassVar['Component'] = 'spbm'
      sps: ClassVar['Component'] = 'sps'
      httpclient_header: ClassVar['Component'] = 'httpclient_header'
      httpclient_content: ClassVar['Component'] = 'httpclient_content'
      vmomi: ClassVar['Component'] = 'vmomi'

   class LogLevel(Enum):
      INFO: ClassVar['LogLevel'] = 'INFO'
      DEBUG: ClassVar['LogLevel'] = 'DEBUG'
      TRACE: ClassVar['LogLevel'] = 'TRACE'

   component: str
   logLevel: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.host import DiskPartitionInfo
from pyVmomi.vim.host import ScsiDisk
from pyVmomi.vim.host import VmfsDatastoreSpec

class VmfsDatastoreExtendSpec(VmfsDatastoreSpec):
   partition: DiskPartitionInfo.Specification
   extent: list[ScsiDisk.Partition] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.guest import GuestAuthentication

class AliasManager(ManagedObject):
   class GuestAuthSubject(DynamicData):
      pass

   class GuestAuthAnySubject(GuestAuthSubject):
      pass

   class GuestAuthNamedSubject(GuestAuthSubject):
      name: str

   class GuestAuthAliasInfo(DynamicData):
      subject: GuestAuthSubject
      comment: str

   class GuestAliases(DynamicData):
      base64Cert: str
      aliases: list[GuestAuthAliasInfo] = []

   class GuestMappedAliases(DynamicData):
      base64Cert: str
      username: str
      subjects: list[GuestAuthSubject] = []

   def AddAlias(self, vm: VirtualMachine, auth: GuestAuthentication, username: str, mapCert: bool, base64Cert: str, aliasInfo: GuestAuthAliasInfo) -> NoReturn: ...
   def RemoveAlias(self, vm: VirtualMachine, auth: GuestAuthentication, username: str, base64Cert: str, subject: GuestAuthSubject) -> NoReturn: ...
   def RemoveAliasByCert(self, vm: VirtualMachine, auth: GuestAuthentication, username: str, base64Cert: str) -> NoReturn: ...
   def ListAliases(self, vm: VirtualMachine, auth: GuestAuthentication, username: str) -> list[GuestAliases]: ...
   def ListMappedAliases(self, vm: VirtualMachine, auth: GuestAuthentication) -> list[GuestMappedAliases]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class VsanObjectSpaceSummary(DynamicData):
   class VsanObjectTypeEnum(Enum):
      vmswap: ClassVar['VsanObjectTypeEnum'] = 'vmswap'
      vdisk: ClassVar['VsanObjectTypeEnum'] = 'vdisk'
      namespace: ClassVar['VsanObjectTypeEnum'] = 'namespace'
      vmem: ClassVar['VsanObjectTypeEnum'] = 'vmem'
      statsdb: ClassVar['VsanObjectTypeEnum'] = 'statsdb'
      iscsiTarget: ClassVar['VsanObjectTypeEnum'] = 'iscsiTarget'
      iscsiLun: ClassVar['VsanObjectTypeEnum'] = 'iscsiLun'
      other: ClassVar['VsanObjectTypeEnum'] = 'other'
      fileSystemOverhead: ClassVar['VsanObjectTypeEnum'] = 'fileSystemOverhead'
      dedupOverhead: ClassVar['VsanObjectTypeEnum'] = 'dedupOverhead'
      spaceUnderDedupConsideration: ClassVar['VsanObjectTypeEnum'] = 'spaceUnderDedupConsideration'
      checksumOverhead: ClassVar['VsanObjectTypeEnum'] = 'checksumOverhead'
      improvedVirtualDisk: ClassVar['VsanObjectTypeEnum'] = 'improvedVirtualDisk'
      transientSpace: ClassVar['VsanObjectTypeEnum'] = 'transientSpace'
      slackSpaceCapRequiredForHost: ClassVar['VsanObjectTypeEnum'] = 'slackSpaceCapRequiredForHost'
      resynPauseThresholdForHost: ClassVar['VsanObjectTypeEnum'] = 'resynPauseThresholdForHost'
      minSpaceRequiredForVsanOp: ClassVar['VsanObjectTypeEnum'] = 'minSpaceRequiredForVsanOp'
      hostRebuildCapacity: ClassVar['VsanObjectTypeEnum'] = 'hostRebuildCapacity'
      physicalTransientSpace: ClassVar['VsanObjectTypeEnum'] = 'physicalTransientSpace'
      haMetadataObject: ClassVar['VsanObjectTypeEnum'] = 'haMetadataObject'
      fileServiceRoot: ClassVar['VsanObjectTypeEnum'] = 'fileServiceRoot'
      attachedCnsVolBlock: ClassVar['VsanObjectTypeEnum'] = 'attachedCnsVolBlock'
      detachedCnsVolBlock: ClassVar['VsanObjectTypeEnum'] = 'detachedCnsVolBlock'
      attachedCnsVolFile: ClassVar['VsanObjectTypeEnum'] = 'attachedCnsVolFile'
      detachedCnsVolFile: ClassVar['VsanObjectTypeEnum'] = 'detachedCnsVolFile'
      cnsVolFile: ClassVar['VsanObjectTypeEnum'] = 'cnsVolFile'
      fileShare: ClassVar['VsanObjectTypeEnum'] = 'fileShare'
      extension: ClassVar['VsanObjectTypeEnum'] = 'extension'
      hbrDisk: ClassVar['VsanObjectTypeEnum'] = 'hbrDisk'
      hbrCfg: ClassVar['VsanObjectTypeEnum'] = 'hbrCfg'
      hbrPersist: ClassVar['VsanObjectTypeEnum'] = 'hbrPersist'
      traceobject: ClassVar['VsanObjectTypeEnum'] = 'traceobject'
      esaObjectOverhead: ClassVar['VsanObjectTypeEnum'] = 'esaObjectOverhead'
      VsanObjectTypeEnum_Unknown: ClassVar['VsanObjectTypeEnum'] = 'VsanObjectTypeEnum_Unknown'

   class VsanObjectTypeEnum90(Enum):
      dedupSharedUserData: ClassVar['VsanObjectTypeEnum90'] = 'dedupSharedUserData'

   objType: Optional[str] = None
   overheadB: Optional[long] = None
   temporaryOverheadB: Optional[long] = None
   primaryCapacityB: Optional[long] = None
   provisionCapacityB: Optional[long] = None
   reservedCapacityB: Optional[long] = None
   overReservedB: Optional[long] = None
   physicalUsedB: Optional[long] = None
   usedB: Optional[long] = None
   objTypeExt: Optional[str] = None
   objTypeExtDesc: Optional[str] = None
   snapshotUsedB: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import VsanUpgradeSystem

from pyVmomi.vim.cluster import VsanDiskFormatConversionCheckResult

class VsanUpgradeStatusEx(VsanUpgradeSystem.UpgradeStatus):
   isPrecheck: Optional[bool] = None
   precheckResult: Optional[VsanDiskFormatConversionCheckResult] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import RuleSpec

from pyVmomi.vim.storageDrs import AutomationConfig
from pyVmomi.vim.storageDrs import IoLoadBalanceConfig
from pyVmomi.vim.storageDrs import OptionSpec
from pyVmomi.vim.storageDrs import SpaceLoadBalanceConfig

class PodConfigSpec(DynamicData):
   enabled: Optional[bool] = None
   ioLoadBalanceEnabled: Optional[bool] = None
   defaultVmBehavior: Optional[str] = None
   loadBalanceInterval: Optional[int] = None
   defaultIntraVmAffinity: Optional[bool] = None
   spaceLoadBalanceConfig: Optional[SpaceLoadBalanceConfig] = None
   ioLoadBalanceConfig: Optional[IoLoadBalanceConfig] = None
   automationOverrides: Optional[AutomationConfig] = None
   rule: list[RuleSpec] = []
   option: list[OptionSpec] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanVcKmipServersHealth

from pyVmomi.vim.host import VsanEncryptionHealthSummary

class VsanClusterEncryptionHealthSummary(DynamicData):
   overallHealth: Optional[str] = None
   configHealth: Optional[str] = None
   kmsHealth: Optional[str] = None
   vcKmsResult: Optional[VsanVcKmipServersHealth] = None
   hostResults: list[VsanEncryptionHealthSummary] = []
   aesniHealth: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import auth as auth
from . import capability as capability
from . import compliance as compliance
from . import fault as fault
from . import placement as placement
from . import profile as profile
from . import provider as provider
from . import replication as replication

from .AboutInfo import AboutInfo as AboutInfo
from .ExtendedElementDescription import ExtendedElementDescription as ExtendedElementDescription
from .LoggingConfiguration import LoggingConfiguration as LoggingConfiguration
from .ServerObjectRef import ServerObjectRef as ServerObjectRef
from .ServiceInstance import ServiceInstance as ServiceInstance
from .ServiceInstanceContent import ServiceInstanceContent as ServiceInstanceContent



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

from pyVmomi.vmodl.fault import SecurityError

class NoPermission(SecurityError):
   class EntityPrivileges(DynamicData):
      entity: ManagedObject
      privilegeIds: list[str] = []

   object: Optional[ManagedObject] = None
   privilegeId: Optional[str] = None
   missingPrivileges: list[EntityPrivileges] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import byte
from pyVmomi.VmomiSupport import short

from pyVmomi.vmodl import DynamicData

class PciDevice(DynamicData):
   id: str
   classId: short
   bus: byte
   slot: byte
   physicalSlot: Optional[int] = None
   slotDescription: Optional[str] = None
   function: byte
   vendorId: short
   subVendorId: short
   vendorName: str
   deviceId: short
   subDeviceId: short
   parentBridge: Optional[str] = None
   deviceName: str
   deviceClassName: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import action as action
from . import alarm as alarm
from . import cluster as cluster
from . import cns as cns
from . import dvs as dvs
from . import encryption as encryption
from . import event as event
from . import ext as ext
from . import fault as fault
from . import host as host
from . import net as net
from . import option as option
from . import profile as profile
from . import scheduler as scheduler
from . import storageDrs as storageDrs
from . import tenant as tenant
from . import vApp as vApp
from . import vcha as vcha
from . import view as view
from . import vm as vm
from . import vsan as vsan
from . import vslm as vslm

from .AboutInfo import AboutInfo as AboutInfo
from .AuthorizationDescription import AuthorizationDescription as AuthorizationDescription
from .AuthorizationManager import AuthorizationManager as AuthorizationManager
from .BatchResult import BatchResult as BatchResult
from .BoolPolicy import BoolPolicy as BoolPolicy
from .Capability import Capability as Capability
from .CertificateManager import CertificateManager as CertificateManager
from .ClusterComputeResource import ClusterComputeResource as ClusterComputeResource
from .ComputeResource import ComputeResource as ComputeResource
from .ConfigSpecOperation import ConfigSpecOperation as ConfigSpecOperation
from .CustomFieldsManager import CustomFieldsManager as CustomFieldsManager
from .CustomizationSpecInfo import CustomizationSpecInfo as CustomizationSpecInfo
from .CustomizationSpecItem import CustomizationSpecItem as CustomizationSpecItem
from .CustomizationSpecManager import CustomizationSpecManager as CustomizationSpecManager
from .Datacenter import Datacenter as Datacenter
from .Datastore import Datastore as Datastore
from .DatastoreNamespaceManager import DatastoreNamespaceManager as DatastoreNamespaceManager
from .Description import Description as Description
from .DesiredSoftwareSpec import DesiredSoftwareSpec as DesiredSoftwareSpec
from .DiagnosticManager import DiagnosticManager as DiagnosticManager
from .DirectPathProfileManager import DirectPathProfileManager as DirectPathProfileManager
from .DistributedVirtualSwitch import DistributedVirtualSwitch as DistributedVirtualSwitch
from .EVCMode import EVCMode as EVCMode
from .ElementDescription import ElementDescription as ElementDescription
from .EnumDescription import EnumDescription as EnumDescription
from .EnvironmentBrowser import EnvironmentBrowser as EnvironmentBrowser
from .ExtendedDescription import ExtendedDescription as ExtendedDescription
from .ExtendedElementDescription import ExtendedElementDescription as ExtendedElementDescription
from .ExtensibleManagedObject import ExtensibleManagedObject as ExtensibleManagedObject
from .Extension import Extension as Extension
from .ExtensionManager import ExtensionManager as ExtensionManager
from .FaultsByHost import FaultsByHost as FaultsByHost
from .FaultsByVM import FaultsByVM as FaultsByVM
from .FeatureEVCMode import FeatureEVCMode as FeatureEVCMode
from .FileManager import FileManager as FileManager
from .Folder import Folder as Folder
from .HbrReplicationTargetSpec import HbrReplicationTargetSpec as HbrReplicationTargetSpec
from .HbrTargetSpec import HbrTargetSpec as HbrTargetSpec
from .HbrTargetSpecReplacement import HbrTargetSpecReplacement as HbrTargetSpecReplacement
from .HealthUpdate import HealthUpdate as HealthUpdate
from .HealthUpdateInfo import HealthUpdateInfo as HealthUpdateInfo
from .HealthUpdateManager import HealthUpdateManager as HealthUpdateManager
from .HistoricalInterval import HistoricalInterval as HistoricalInterval
from .HistoryCollector import HistoryCollector as HistoryCollector
from .HostServiceTicket import HostServiceTicket as HostServiceTicket
from .HostSystem import HostSystem as HostSystem
from .HttpNfcLease import HttpNfcLease as HttpNfcLease
from .ImportSpec import ImportSpec as ImportSpec
from .InheritablePolicy import InheritablePolicy as InheritablePolicy
from .IntExpression import IntExpression as IntExpression
from .IntPolicy import IntPolicy as IntPolicy
from .IoFilterManager import IoFilterManager as IoFilterManager
from .IpAddress import IpAddress as IpAddress
from .IpPoolManager import IpPoolManager as IpPoolManager
from .IpRange import IpRange as IpRange
from .KeyValue import KeyValue as KeyValue
from .LatencySensitivity import LatencySensitivity as LatencySensitivity
from .LicenseAssignmentManager import LicenseAssignmentManager as LicenseAssignmentManager
from .LicenseManager import LicenseManager as LicenseManager
from .LocalizationManager import LocalizationManager as LocalizationManager
from .LongPolicy import LongPolicy as LongPolicy
from .MacAddress import MacAddress as MacAddress
from .MacRange import MacRange as MacRange
from .ManagedEntity import ManagedEntity as ManagedEntity
from .MethodDescription import MethodDescription as MethodDescription
from .NegatableExpression import NegatableExpression as NegatableExpression
from .Network import Network as Network
from .NumericRange import NumericRange as NumericRange
from .OpaqueNetwork import OpaqueNetwork as OpaqueNetwork
from .OverheadMemoryManager import OverheadMemoryManager as OverheadMemoryManager
from .OvfManager import OvfManager as OvfManager
from .PasswordField import PasswordField as PasswordField
from .PerformanceDescription import PerformanceDescription as PerformanceDescription
from .PerformanceManager import PerformanceManager as PerformanceManager
from .PosixUserSearchResult import PosixUserSearchResult as PosixUserSearchResult
from .PrivilegePolicyDef import PrivilegePolicyDef as PrivilegePolicyDef
from .ResourceAllocationInfo import ResourceAllocationInfo as ResourceAllocationInfo
from .ResourceAllocationOption import ResourceAllocationOption as ResourceAllocationOption
from .ResourceConfigOption import ResourceConfigOption as ResourceConfigOption
from .ResourceConfigSpec import ResourceConfigSpec as ResourceConfigSpec
from .ResourcePlanningManager import ResourcePlanningManager as ResourcePlanningManager
from .ResourcePool import ResourcePool as ResourcePool
from .SDDCBase import SDDCBase as SDDCBase
from .SearchIndex import SearchIndex as SearchIndex
from .SelectionSet import SelectionSet as SelectionSet
from .ServiceInstance import ServiceInstance as ServiceInstance
from .ServiceInstanceContent import ServiceInstanceContent as ServiceInstanceContent
from .ServiceLocator import ServiceLocator as ServiceLocator
from .ServiceManager import ServiceManager as ServiceManager
from .SessionManager import SessionManager as SessionManager
from .SharesInfo import SharesInfo as SharesInfo
from .SharesOption import SharesOption as SharesOption
from .SimpleCommand import SimpleCommand as SimpleCommand
from .SingleIp import SingleIp as SingleIp
from .SingleMac import SingleMac as SingleMac
from .SiteInfo import SiteInfo as SiteInfo
from .SiteInfoManager import SiteInfoManager as SiteInfoManager
from .StoragePod import StoragePod as StoragePod
from .StorageQueryManager import StorageQueryManager as StorageQueryManager
from .StorageResourceManager import StorageResourceManager as StorageResourceManager
from .StringExpression import StringExpression as StringExpression
from .StringPolicy import StringPolicy as StringPolicy
from .Tag import Tag as Tag
from .Task import Task as Task
from .TaskDescription import TaskDescription as TaskDescription
from .TaskFilterSpec import TaskFilterSpec as TaskFilterSpec
from .TaskHistoryCollector import TaskHistoryCollector as TaskHistoryCollector
from .TaskInfo import TaskInfo as TaskInfo
from .TaskInfoFilterSpec import TaskInfoFilterSpec as TaskInfoFilterSpec
from .TaskManager import TaskManager as TaskManager
from .TaskReason import TaskReason as TaskReason
from .TaskReasonAlarm import TaskReasonAlarm as TaskReasonAlarm
from .TaskReasonSchedule import TaskReasonSchedule as TaskReasonSchedule
from .TaskReasonSystem import TaskReasonSystem as TaskReasonSystem
from .TaskReasonUser import TaskReasonUser as TaskReasonUser
from .TypeDescription import TypeDescription as TypeDescription
from .UpdateVirtualMachineFilesResult import UpdateVirtualMachineFilesResult as UpdateVirtualMachineFilesResult
from .UserDirectory import UserDirectory as UserDirectory
from .UserSearchResult import UserSearchResult as UserSearchResult
from .UserSession import UserSession as UserSession
from .VVolVmConfigFileUpdateResult import VVolVmConfigFileUpdateResult as VVolVmConfigFileUpdateResult
from .VasaStorageArray import VasaStorageArray as VasaStorageArray
from .VimVasaProvider import VimVasaProvider as VimVasaProvider
from .VimVasaProviderInfo import VimVasaProviderInfo as VimVasaProviderInfo
from .VirtualApp import VirtualApp as VirtualApp
from .VirtualDiskManager import VirtualDiskManager as VirtualDiskManager
from .VirtualMachine import VirtualMachine as VirtualMachine
from .VirtualizationManager import VirtualizationManager as VirtualizationManager
from .VsanComparator import VsanComparator as VsanComparator
from .VsanCompositeConstraint import VsanCompositeConstraint as VsanCompositeConstraint
from .VsanCompositeConstraintConjoinerEnum import VsanCompositeConstraintConjoinerEnum as VsanCompositeConstraintConjoinerEnum
from .VsanDataObfuscationRule import VsanDataObfuscationRule as VsanDataObfuscationRule
from .VsanJsonComparator import VsanJsonComparator as VsanJsonComparator
from .VsanJsonFilterRule import VsanJsonFilterRule as VsanJsonFilterRule
from .VsanMassCollector import VsanMassCollector as VsanMassCollector
from .VsanMassCollectorObjectCollectionEnum import VsanMassCollectorObjectCollectionEnum as VsanMassCollectorObjectCollectionEnum
from .VsanMassCollectorPropertyParams import VsanMassCollectorPropertyParams as VsanMassCollectorPropertyParams
from .VsanMassCollectorSpec import VsanMassCollectorSpec as VsanMassCollectorSpec
from .VsanNestJsonComparator import VsanNestJsonComparator as VsanNestJsonComparator
from .VsanObjectTypeRule import VsanObjectTypeRule as VsanObjectTypeRule
from .VsanPhoneHomeSystem import VsanPhoneHomeSystem as VsanPhoneHomeSystem
from .VsanPropertyConstraint import VsanPropertyConstraint as VsanPropertyConstraint
from .VsanPropertyConstraintComparatorEnum import VsanPropertyConstraintComparatorEnum as VsanPropertyConstraintComparatorEnum
from .VsanRegexBasedRule import VsanRegexBasedRule as VsanRegexBasedRule
from .VsanResourceConstraint import VsanResourceConstraint as VsanResourceConstraint
from .VsanUpgradeSystem import VsanUpgradeSystem as VsanUpgradeSystem
from .VsanUpgradeSystemEx import VsanUpgradeSystemEx as VsanUpgradeSystemEx



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import ElementDescription

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import Fru

class NumericSensorInfo(DynamicData):
   class HealthState(Enum):
      unknown: ClassVar['HealthState'] = 'unknown'
      green: ClassVar['HealthState'] = 'green'
      yellow: ClassVar['HealthState'] = 'yellow'
      red: ClassVar['HealthState'] = 'red'

   class SensorType(Enum):
      fan: ClassVar['SensorType'] = 'fan'
      power: ClassVar['SensorType'] = 'power'
      temperature: ClassVar['SensorType'] = 'temperature'
      voltage: ClassVar['SensorType'] = 'voltage'
      other: ClassVar['SensorType'] = 'other'
      processor: ClassVar['SensorType'] = 'processor'
      memory: ClassVar['SensorType'] = 'memory'
      storage: ClassVar['SensorType'] = 'storage'
      systemBoard: ClassVar['SensorType'] = 'systemBoard'
      battery: ClassVar['SensorType'] = 'battery'
      bios: ClassVar['SensorType'] = 'bios'
      cable: ClassVar['SensorType'] = 'cable'
      watchdog: ClassVar['SensorType'] = 'watchdog'

   name: str
   healthState: Optional[ElementDescription] = None
   currentReading: long
   unitModifier: int
   baseUnits: str
   rateUnits: Optional[str] = None
   sensorType: str
   id: Optional[str] = None
   sensorNumber: Optional[long] = None
   timeStamp: Optional[str] = None
   fru: Optional[Fru] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterHealthAction
from pyVmomi.vim.cluster import VsanClusterHealthResultBase
from pyVmomi.vim.cluster import VsanHealthCorrelation
from pyVmomi.vim.cluster import VsanHistoricalHealthTest

class VsanClusterHealthTest(DynamicData):
   testId: Optional[str] = None
   testName: Optional[str] = None
   testDescription: Optional[str] = None
   testShortDescription: Optional[str] = None
   testHealthyEntities: Optional[int] = None
   testAllEntities: Optional[int] = None
   testHealth: Optional[str] = None
   testDetails: list[VsanClusterHealthResultBase] = []
   testActions: list[VsanClusterHealthAction] = []
   historicalResults: list[VsanHistoricalHealthTest] = []
   testCorrelation: Optional[VsanHealthCorrelation] = None
   reducedScore: Optional[int] = None
   category: Optional[str] = None
   riskIfNotFix: Optional[str] = None
   lastStatusChangeTime: Optional[datetime] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import HostSystem
from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.fault import InvalidVmConfig

class VmWwnConflict(InvalidVmConfig):
   vm: Optional[VirtualMachine] = None
   host: Optional[HostSystem] = None
   name: Optional[str] = None
   wwn: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vmodl import DynamicData

from pyVmomi.vslm import AboutInfo
from pyVmomi.vslm import StorageLifecycleManager

from pyVmomi.vslm.auth import SessionManager

from pyVmomi.vslm.vso import VStorageObjectManager

class ServiceInstanceContent(DynamicData):
   aboutInfo: AboutInfo
   sessionManager: SessionManager
   vStorageObjectManager: VStorageObjectManager
   storageLifecycleManager: StorageLifecycleManager



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Task
from pyVmomi.vim import TaskInfo

from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.scheduler import ScheduledTask
from pyVmomi.vim.scheduler import ScheduledTaskSpec

class ScheduledTaskInfo(ScheduledTaskSpec):
   scheduledTask: ScheduledTask
   entity: ManagedEntity
   lastModifiedTime: datetime
   lastModifiedUser: str
   nextRunTime: Optional[datetime] = None
   prevRunTime: Optional[datetime] = None
   state: TaskInfo.State
   error: Optional[MethodFault] = None
   result: Optional[object] = None
   progress: Optional[int] = None
   activeTask: Optional[Task] = None
   taskObject: ManagedObject
